@@ -1,9 +1,11 @@
 package Graphics::Primitive::Insets;
 use Moose;
+use MooseX::Storage;
 
 with 'Geometry::Primitive::Equal';
 
 with 'MooseX::Clone';
+with Storage (format => 'JSON', io => 'File');
 
 use Moose::Util::TypeConstraints;
 
